package relex.entity;

/**
 * 
 * @author Borislav Iordanov
 *
 */
public enum EntityType
{
	GENERIC,
	DATE,
	EMOTICON,
	LOCATION,
	MEASURE,
	MONEY,
	ORGANIZATION,
	PERSON,
	PUNCTUATION,
	TIME;
}
